@@ -55,9 +55,9 @@ class KWin4Doc : public KGame
       */
     explicit KWin4Doc(QWidget *parent);
 
-    /** The dstructor.
+    /** The destructor.
       */
-    ~KWin4Doc();
+    ~KWin4Doc() override;
 
     /** Adds a view to the document which displays the document contents.
       * @param view The view to add
@@ -74,7 +74,7 @@ class KWin4Doc : public KGame
       * @param reset   Reset parameter forward to KGame
       * @return True on success, false otherwise.
       */	
-    bool loadgame(QDataStream &stream, bool network, bool reset) Q_DECL_OVERRIDE;
+    bool loadgame(QDataStream &stream, bool network, bool reset) override;
 
     /** Read the game config from the config file.
       * @param config The config 
@@ -199,13 +199,13 @@ class KWin4Doc : public KGame
       * @param io    The IO mode 
       * @param isvirtual True for network players (without physical IO)
       */
-    KPlayer* createPlayer(int rtti, int io, bool isvirtual) Q_DECL_OVERRIDE;
+    KPlayer* createPlayer(int rtti, int io, bool isvirtual) override;
 
     /** KGame function to determine the next player. In KWin4 players alternate.
       * @param last      The last player to move
       * @param exclusive unused
       */
-    KPlayer* nextPlayer(KPlayer* last, bool exclusive=true) Q_DECL_OVERRIDE;
+    KPlayer* nextPlayer(KPlayer* last, bool exclusive=true) override;
 
     /** This is also an overwritten function of KGame. It is
       * called in the game negotiation upon connect. Here
@@ -215,7 +215,7 @@ class KWin4Doc : public KGame
       * @param newList  List of new players
       * @param inactive List of inactive players
       */
-    void newPlayersJoin(KGamePlayerList* list, KGamePlayerList* newList, QList<int>& inactive) Q_DECL_OVERRIDE;
+    void newPlayersJoin(KGamePlayerList* list, KGamePlayerList* newList, QList<int>& inactive) override;
 
     /** Reset the whole game to the beginning (clear board, ...)
       * @param initview  If true also reset the view
@@ -237,12 +237,12 @@ class KWin4Doc : public KGame
       */
     bool doMove(int x, int id);
 
-    /** Check whether the field has a game over situation. KGame stanard
+    /** Check whether the field has a game over situation. KGame standard
       * function.
       * @param player The current player
-      * @return -1: remis, 1: won, 0: continue game
+      * @return -1: draw, 1: won, 0: continue game
       */
-    int checkGameOver(KPlayer *player) Q_DECL_OVERRIDE;
+    int checkGameOver(KPlayer *player) override;
 
     /** Check whether the field has a game over situation. Called by
       * above standard KGame function but with more suitable parameters.
@@ -262,10 +262,10 @@ class KWin4Doc : public KGame
       * the central input for all player inputs. Mouse, Keyboard
       * AI or network end here in the same format. A move is
       * initiated here.
-      * @param msg    The game move messasge 
+      * @param msg    The game move message 
       * @param player The sender player
       */
-    bool playerInput(QDataStream& msg, KPlayer* player) Q_DECL_OVERRIDE;
+    bool playerInput(QDataStream& msg, KPlayer* player) override;
 
     /** Set the IO devices new.
       */
@@ -302,7 +302,7 @@ class KWin4Doc : public KGame
       */
     COLOUR getPlayerColour(int player);
 
-  public slots:
+  public Q_SLOTS:
     /** Indication from the view that a move has been displayed. Now
       * The next player can be switched.
       * @param mode A user defined (unused) mode
@@ -314,8 +314,8 @@ class KWin4Doc : public KGame
       */
     void loadSettings();
 
-  protected slots:  
-    /** Initiate a repeate of the move. This happens if somehow the player
+  protected Q_SLOTS:  
+    /** Initiate a repeat of the move. This happens if somehow the player
       * input created an invalid move. The same player has to input again.
       */
     void repeatMove();
@@ -372,22 +372,22 @@ class KWin4Doc : public KGame
       */
     void gamePropertyChanged(KGamePropertyBase* prop, KGame* me);
 
-    /** Reveived a debug message from the AI (debug only)
+    /** Received a debug message from the AI (debug only)
       * @param s The message
       */
     void receivedStderr(const QString &s);
 
-  signals:
-    /** Emmitted if the game status changes to run.
+  Q_SIGNALS:
+    /** Emitted if the game status changes to run.
       */
     void signalGameRun();
 
-    /** Emmitted if the chat origin changes.
+    /** Emitted if the chat origin changes.
       * @param player The affected player
       */
     void signalChatChanged(KWin4Player* player);
 
-    /** Emmitted when the next players move is due.
+    /** Emitted when the next players move is due.
       * @param playerNumber The number of the player
       */
     void signalNextPlayer(int playerNumber);
